@@ -1,4 +1,4 @@
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
 pub enum LintingError {
     NonAngularType,
     EmptyScope,
@@ -8,7 +8,6 @@ pub enum LintingError {
     NoDescription,
 }
 
-#[derive(Debug)]
 pub struct Commit {
     pub oid: git2::Oid,
     pub message: String,
